@@ -28,6 +28,14 @@ val unlock_request_handling : unit -> unit
 
 (** {2 Mobile applications} *)
 
+val init_client_app
+  :  app_name:string
+  -> ?ssl:bool
+  -> hostname:string
+  -> ?port:int
+  -> site_dir:Eliom_lib.Url.path
+  -> unit
+  -> unit
 (** Call this function if you want to be able to run your client side
     app before doing the first request, that is, when the client side
     app is not sent by the server. This may be the case for example if
@@ -42,13 +50,8 @@ val unlock_request_handling : unit -> unit
     [site_dir] (if given) specifies the path that the application runs
     under. It should correspond to the <site> tag of your server
     configuration. Calls to server functions use this path. *)
-val init_client_app :
-  app_name:string ->
-  ?ssl:bool ->
-  hostname:string ->
-  ?port:int ->
-  site_dir:Eliom_lib.Url.path -> unit -> unit
 
+val is_client_app : unit -> bool
 (** Returns whether the application is sent by a server or started on
     client side. If called on server side, always returns [false].
     Otherwise, it tests the presence of JS variables added automatically by
@@ -57,11 +60,31 @@ val init_client_app :
     {[ if not (Eliom_client.is_client_app ())
  then Eliom_client.init_client_app ... ]}
 *)
-val is_client_app : unit -> bool
-
 
 (** {2 Calling services} *)
 
+val change_page
+  :  ?ignore_client_fun:bool
+  -> ?replace:bool
+  -> ?window_name:string
+  -> ?window_features:string
+  -> ?absolute:bool
+  -> ?absolute_path:bool
+  -> ?https:bool
+  -> service:
+       ('a, 'b, _, _, _, _, _, _, _, _, Eliom_service.non_ocaml) Eliom_service.t
+  -> ?hostname:string
+  -> ?port:int
+  -> ?fragment:string
+  -> ?keep_nl_params:[`All | `None | `Persistent]
+  -> ?nl_params:Eliom_parameter.nl_params_set
+  -> ?keep_get_na_params:bool
+  -> ?progress:(int -> int -> unit)
+  -> ?upload_progress:(int -> int -> unit)
+  -> ?override_mime_type:string
+  -> 'a
+  -> 'b
+  -> unit Lwt.t
 (** Call a service and change the current page.  If the service
     belongs to the same application, the client side program is not
     stopped, and only the content (not the container) is reloaded.  If
@@ -72,28 +95,36 @@ val is_client_app : unit -> bool
     If [window_name] is provided and not "_self" (for example ["_blank"]),
     will behave as [exit_to].
 *)
-val change_page :
-  ?ignore_client_fun:bool ->
-  ?replace:bool ->
-  ?window_name:string ->
-  ?window_features:string ->
-  ?absolute:bool ->
-  ?absolute_path:bool ->
-  ?https:bool ->
-  service:
-    ('a, 'b, _, _, _, _, _, _, _, _, Eliom_service.non_ocaml)
-      Eliom_service.t ->
-  ?hostname:string ->
-  ?port:int ->
-  ?fragment:string ->
-  ?keep_nl_params:[ `All | `None | `Persistent ] ->
-  ?nl_params:Eliom_parameter.nl_params_set ->
-  ?keep_get_na_params:bool ->
-  ?progress:(int -> int -> unit) ->
-  ?upload_progress:(int -> int -> unit) ->
-  ?override_mime_type:string ->
-  'a -> 'b -> unit Lwt.t
 
+val call_ocaml_service
+  :  ?absolute:bool
+  -> ?absolute_path:bool
+  -> ?https:bool
+  -> service:
+       ( 'a
+       , 'b
+       , _
+       , _
+       , _
+       , _
+       , _
+       , _
+       , _
+       , _
+       , 'return Eliom_service.ocaml )
+       Eliom_service.t
+  -> ?hostname:string
+  -> ?port:int
+  -> ?fragment:string
+  -> ?keep_nl_params:[`All | `None | `Persistent]
+  -> ?nl_params:Eliom_parameter.nl_params_set
+  -> ?keep_get_na_params:bool
+  -> ?progress:(int -> int -> unit)
+  -> ?upload_progress:(int -> int -> unit)
+  -> ?override_mime_type:string
+  -> 'a
+  -> 'b
+  -> 'return Lwt.t
 (** Call a server side service that return an OCaml value.
 
     If the service raises an exception, the call to the
@@ -103,25 +134,24 @@ val change_page :
     (NB that we cannot send the original exception as-it, because
     OCaml permits the marshalling of exceptions ...)
 *)
-val call_ocaml_service :
-  ?absolute:bool ->
-  ?absolute_path:bool ->
-  ?https:bool ->
-  service:
-    ('a, 'b, _, _, _, _, _, _, _, _, 'return Eliom_service.ocaml)
-      Eliom_service.t ->
-  ?hostname:string ->
-  ?port:int ->
-  ?fragment:string ->
-  ?keep_nl_params:[ `All | `None | `Persistent ] ->
-  ?nl_params:Eliom_parameter.nl_params_set ->
-  ?keep_get_na_params:bool ->
-  ?progress:(int -> int -> unit) ->
-  ?upload_progress:(int -> int -> unit) ->
-  ?override_mime_type:string ->
-  'a -> 'b -> 'return Lwt.t
-
 
+val exit_to
+  :  ?window_name:string
+  -> ?window_features:string
+  -> ?absolute:bool
+  -> ?absolute_path:bool
+  -> ?https:bool
+  -> service:
+       ('a, 'b, _, _, _, _, _, _, _, _, Eliom_service.non_ocaml) Eliom_service.t
+  -> ?hostname:string
+  -> ?port:int
+  -> ?fragment:string
+  -> ?keep_nl_params:[`All | `None | `Persistent]
+  -> ?nl_params:Eliom_parameter.nl_params_set
+  -> ?keep_get_na_params:bool
+  -> 'a
+  -> 'b
+  -> unit
 (** Stop current program and load a new page.  Note that for string arguments,
     sole line feed or sole carriage return characters are substituted by the
     string ["\r\n"].
@@ -132,82 +162,80 @@ val call_ocaml_service :
     Warning: opening in other window may not work on mobile apps
     if [window.open] is not implemented.
 *)
-val exit_to :
-  ?window_name:string ->
-  ?window_features:string ->
-  ?absolute:bool ->
-  ?absolute_path:bool ->
-  ?https:bool ->
-  service:
-    ('a, 'b, _, _, _, _, _, _, _, _, Eliom_service.non_ocaml)
-      Eliom_service.t ->
-  ?hostname:string ->
-  ?port:int ->
-  ?fragment:string ->
-  ?keep_nl_params:[ `All | `None | `Persistent ] ->
-  ?nl_params:Eliom_parameter.nl_params_set ->
-  ?keep_get_na_params:bool ->
-  'a -> 'b -> unit
 
+val window_open
+  :  window_name:Js.js_string Js.t
+  -> ?window_features:Js.js_string Js.t
+  -> ?absolute:bool
+  -> ?absolute_path:bool
+  -> ?https:bool
+  -> service:
+       ('a, unit, Eliom_service.get, _, _, _, _, _, _, unit, _) Eliom_service.t
+  -> ?hostname:string
+  -> ?port:int
+  -> ?fragment:string
+  -> ?keep_nl_params:[`All | `None | `Persistent]
+  -> ?nl_params:Eliom_parameter.nl_params_set
+  -> ?keep_get_na_params:bool
+  -> 'a
+  -> Dom_html.window Js.t Js.opt
 (** Loads an Eliom service in a window (cf. Javascript's [window.open]).
 *)
-val window_open :
-  window_name:Js.js_string Js.t  ->
-  ?window_features:Js.js_string Js.t ->
-  ?absolute:bool ->
-  ?absolute_path:bool ->
-  ?https:bool ->
-  service:
-    ('a, unit, Eliom_service.get, _, _, _, _, _, _, unit, _)
-      Eliom_service.t ->
-  ?hostname:string ->
-  ?port:int ->
-  ?fragment:string ->
-  ?keep_nl_params:[ `All | `None | `Persistent ] ->
-  ?nl_params:Eliom_parameter.nl_params_set ->
-  ?keep_get_na_params:bool ->
-  'a -> Dom_html.window Js.t Js.opt
 
+val change_url
+  :  ?replace:bool
+  -> ?absolute:bool
+  -> ?absolute_path:bool
+  -> ?https:bool
+  -> service:
+       ( 'get
+       , unit
+       , Eliom_service.get
+       , _
+       , _
+       , _
+       , _
+       , _
+       , _
+       , unit
+       , _ )
+       Eliom_service.t
+  -> ?hostname:string
+  -> ?port:int
+  -> ?fragment:string
+  -> ?keep_nl_params:[`All | `None | `Persistent]
+  -> ?nl_params:Eliom_parameter.nl_params_set
+  -> 'get
+  -> unit
 (** Changes the URL, without doing a request.
     It takes a GET (co-)service as parameter and its parameters.
     If the [replace] flag is set, the current page is not saved
     in the history.
  *)
-val change_url :
-  ?replace:bool ->
-  ?absolute:bool ->
-  ?absolute_path:bool ->
-  ?https:bool ->
-  service:
-    ('get, unit, Eliom_service.get,
-     _, _, _, _, _, _, unit, _) Eliom_service.t ->
-  ?hostname:string ->
-  ?port:int ->
-  ?fragment:string ->
-  ?keep_nl_params:[ `All | `None | `Persistent ] ->
-  ?nl_params:Eliom_parameter.nl_params_set ->
-  'get -> unit
 
+val call_service
+  :  ?absolute:bool
+  -> ?absolute_path:bool
+  -> ?https:bool
+  -> service:('a, 'b, _, _, _, _, _, _, _, _, _) Eliom_service.t
+  -> ?hostname:string
+  -> ?port:int
+  -> ?fragment:string
+  -> ?keep_nl_params:[`All | `None | `Persistent]
+  -> ?nl_params:Eliom_parameter.nl_params_set
+  -> ?keep_get_na_params:bool
+  -> ?progress:(int -> int -> unit)
+  -> ?upload_progress:(int -> int -> unit)
+  -> ?override_mime_type:string
+  -> 'a
+  -> 'b
+  -> string Lwt.t
 (** (low level) Call a server side service and return the content
     of the resulting HTTP frame as a string. *)
-val call_service :
-  ?absolute:bool ->
-  ?absolute_path:bool ->
-  ?https:bool ->
-  service:('a, 'b, _, _, _, _, _, _, _, _, _) Eliom_service.t ->
-  ?hostname:string ->
-  ?port:int ->
-  ?fragment:string ->
-  ?keep_nl_params:[ `All | `None | `Persistent ] ->
-  ?nl_params:Eliom_parameter.nl_params_set ->
-  ?keep_get_na_params:bool ->
-  ?progress:(int -> int -> unit) ->
-  ?upload_progress:(int -> int -> unit) ->
-  ?override_mime_type:string ->
-  'a -> 'b -> string Lwt.t
 
 (** {2 Misc} *)
 
+val onload : (unit -> unit) -> unit
 (** Registers some code to be executed after loading the client
     application, or after changing the page the next time.
 
@@ -244,11 +272,16 @@ val call_service :
     >> %}
 
 *)
-val onload : (unit -> unit) -> unit
 
-(** Returns a Lwt thread that waits until the next page is loaded. *)
 val lwt_onload : unit -> unit Lwt.t
+(** Returns a Lwt thread that waits until the next page is loaded. *)
 
+type changepage_event =
+  { in_cache : bool
+  ; origin_uri : string
+  ; target_uri : string
+  ; origin_id : int
+  ; target_id : int option }
 (** [changepage_event] is a record of some parameters related to
     page changes. [in_cache] is true if the dom of the page is cached by
     [push_history_dom].
@@ -257,18 +290,12 @@ val lwt_onload : unit -> unit Lwt.t
     the current page and [target_id] is the state_id of the next page.
     [target_id] is not [None] if and only if the onchangepage event
     takes place during a navigation in history. *)
-type changepage_event =
-  {in_cache:bool;
-   origin_uri:string;
-   target_uri:string;
-   origin_id:int;
-   target_id:int option}
 
+val onchangepage : (changepage_event -> unit Lwt.t) -> unit
 (** Run some code *before* the next page change, that is, before each
     call to a page-producing service handler.
     Just like onpreload, handlers registered with onchangepage only
     apply to the next page change. *)
-val onchangepage : (changepage_event -> unit Lwt.t) -> unit
 
 module Page_status : sig
   (** a page can be in one of the following states:
@@ -279,10 +306,10 @@ module Page_status : sig
       - [Dead]: page is in the browser history without its DOM being cached *)
   type t = Generating | Active | Cached | Dead
 
+  val signal : unit -> t React.S.t
   (** retrieves a react signal for the status of the current page; note that the
       `current page' is not necessarily the page currently being displayed, but
       rather the page in whose context the current code is executed. *)
-  val signal : unit -> t React.S.t
 
   (** convenience functions for retrieving a react event for the current page
       that is triggered whenever it reaches the respective status *)
@@ -290,10 +317,17 @@ module Page_status : sig
     val active : unit -> unit React.E.t
     val cached : unit -> unit React.E.t
     val dead : unit -> unit React.E.t
+
     val inactive : unit -> unit React.E.t
     (** [inactive] occurs when the [Active] state is left ([Cached] or [Dead]) *)
   end
 
+  val onactive
+    :  ?now:bool
+    -> ?once:bool
+    -> ?stop:unit React.E.t
+    -> (unit -> unit)
+    -> unit
   (** [onactive] is convenience function that attaches a handler to
       [Events.active], which behaves exactly like [fun f -> React.E.map f
       Events.active].
@@ -310,31 +344,21 @@ module Page_status : sig
       listeners of [Dom_html.window]) are killed on a page change and not
       automatically restored with the DOM (contrary to event listeners attached
       to DOM elements). *)
-  val onactive :
-    ?now:bool ->
-    ?once:bool ->
-    ?stop:(unit React.E.t) ->
-    (unit -> unit) -> unit
-  val oncached :
-    ?once:bool ->
-    ?stop:(unit React.E.t) ->
-    (unit -> unit) -> unit
-  val ondead :
-    ?stop:(unit React.E.t) ->
-    (unit -> unit) -> unit
-  val oninactive :
-    ?once:bool ->
-    ?stop:(unit React.E.t) ->
-    (unit -> unit) -> unit
 
+  val oncached : ?once:bool -> ?stop:unit React.E.t -> (unit -> unit) -> unit
+  val ondead : ?stop:unit React.E.t -> (unit -> unit) -> unit
+  val oninactive : ?once:bool -> ?stop:unit React.E.t -> (unit -> unit) -> unit
+
+  val while_active
+    :  ?now:bool
+    -> ?stop:unit React.E.t
+    -> (unit -> unit Lwt.t)
+    -> unit
   (** [while_active] initiates an action as [onactive] but cancels it whenever
       the page is not active anymore. *)
-  val while_active :
-    ?now:bool ->
-    ?stop:(unit React.E.t) ->
-    (unit -> unit Lwt.t) -> unit
 end
 
+val onbeforeunload : (unit -> string option) -> unit
 (** [onbeforeunload f] registers [f] as a handler to be called before
     changing the page the next time. If [f] returns [Some s], then we
     ask the user to confirm quitting. We try to use [s] in the
@@ -347,29 +371,29 @@ end
     https://bugzilla.mozilla.org/show_bug.cgi?id=641509
 
     [onbeforeunload] can be used to register multiple callbacks. *)
-val onbeforeunload : (unit -> string option) -> unit
 
+val onunload : (unit -> unit) -> unit
 (** [onunload f] registers [f] as a handler to be called before page
     change. The callback [f] is sometimes triggered by internal
     service calls, and sometimes by the browser [onunload] event.
     [onunload] can be used to register multiple callbacks. *)
-val onunload : (unit -> unit) -> unit
 
-(** Wait for the initialization phase to terminate *)
 val wait_load_end : unit -> unit Lwt.t
+(** Wait for the initialization phase to terminate *)
 
+val get_application_name : unit -> string
 (** Returns the name of currently running Eliom application,
     defined while applying [Eliom_registration.App] functor. *)
-val get_application_name : unit -> string
 
+val persist_document_head : unit -> unit
 (** After this function is called, the document head is no
     longer changed on page change. *)
-val persist_document_head : unit -> unit
 
 (** {2 RPC / Server functions}
 
     See the {% <<a_manual chapter="clientserver-communication" fragment="rpc"|manual>> %}.*)
 
+type ('a, +'b) server_function = 'a -> 'b Lwt.t
 (** A [('a, 'b) server_function] provides transparently access to a
     server side function which has been created by {% <<a_api
     subproject="server"| val Eliom_client.server_function>> %}.
@@ -380,8 +404,8 @@ val persist_document_head : unit -> unit
     The handling of exception on the server corresponds to that of
     <<a_api subproject="client"|val Eliom_client.call_ocaml_service>>.
 *)
-type ('a, +'b) server_function = 'a -> 'b Lwt.t
 
+val change_page_uri : ?replace:bool -> string -> unit Lwt.t
 (** [change_page_uri ?replace uri] identifies and calls the
     client-side service that implements [uri].
 
@@ -390,45 +414,45 @@ type ('a, +'b) server_function = 'a -> 'b Lwt.t
 
     If the [replace] flag is set to [true], the current page is not
     saved in the history. *)
-val change_page_uri : ?replace:bool -> string -> unit Lwt.t
 
+val set_client_html_file : string -> unit
 (** Set the name of the HTML file loading our client app. The default
     is "eliom.html". A wrong value will not allow the app to
     initialize itself correctly. *)
-val set_client_html_file : string -> unit
 
 (**/**)
 
+val change_page_unknown
+  :  ?meth:[`Get | `Post | `Put | `Delete]
+  -> ?hostname:string
+  -> ?replace:bool
+  -> string list
+  -> (string * string) list
+  -> (string * string) list
+  -> unit Lwt.t
 (** [change_page_unknown path get_params post_params] calls the
     service corresponding to [(path, get_params, post_params)]. It may
     throw [Eliom_common.Eliom_404] or
     [Eliom_common.Eliom_Wrong_parameter] if there is no appropriate
     service available. *)
-val change_page_unknown :
-  ?meth:[`Get | `Post | `Put | `Delete] ->
-  ?hostname:string ->
-  ?replace:bool ->
-  string list ->
-  (string * string) list ->
-  (string * string) list ->
-  unit Lwt.t
 
 (* Documentation rather in eliom_client.ml *)
 
 val init : unit -> unit
-
 val set_reload_function : (unit -> unit -> Eliom_service.result Lwt.t) -> unit
 
 module History : sig
-
+  val past : unit -> string list
   (** get the URLs of the last pages visited (within the app) in reverse temporal order. *)
-  val past : unit -> string list (*tmp*)
 
+  (*tmp*)
+
+  val future : unit -> string list
   (** get the URLs of the pages visited before having navigated backwards in history. *)
-  val future : unit -> string list (*tmp*)
-
+  (*tmp*)
 end
 
+val push_history_dom : unit -> unit
 (** [push_history_dom] stores the document/body of the current page so
     that the next time when we encounter the page while navigating through the
     history, the DOM will be recovered from the cache instead of recharging or
@@ -459,7 +483,6 @@ end
         register ()
     >> %}
 *)
-val push_history_dom : unit -> unit
 
 (* [set_max_dist_history_doms (Some n)] limits the number of cached DOMs
    that are kept in memory. Thereby [n] is the maximum distance in history from
@@ -467,11 +490,11 @@ val push_history_dom : unit -> unit
    previous and the next page are kept. *)
 val set_max_dist_history_doms : int option -> unit
 
-(** Lwt_log section for this module. *)
 val section : Lwt_log.section
+(** Lwt_log section for this module. *)
 
-(** Is it a middle-click event? *)
 val middleClick : Dom_html.mouseEvent Js.t -> bool
+(** Is it a middle-click event? *)
 
 type client_form_handler = Dom_html.event Js.t -> bool Lwt.t
 
