@@ -60,8 +60,8 @@ let add_unregistered _ _ = ()
 module To_and_of_shared = struct
   type 'a t = 'a to_and_of
 
-  let of_string {of_string} = of_string
-  let to_string {to_string} = to_string
+  let of_string {of_string; _} = of_string
+  let to_string {to_string; _} = to_string
   let to_and_of tao = tao
 end
 
