@@ -35,48 +35,50 @@ v}
 
 *)
 
-
+val get_default_hostname : unit -> string
 (** The function [get_default_hostname ()]returns the hostname
     declared in the config file ([<host defaulthostname="...">]) or
     the default machine hostname.
     In that case, absolute URL will use that hostname. *)
-val get_default_hostname : unit -> string
 
+val get_default_port : unit -> int
 (** The function [get_default_port ()] returns the port number
     declared in the config file ([<host defaulthttpport="...">]) or
     80 if undeclared.
 *)
-val get_default_port : unit -> int
 
+val get_default_sslport : unit -> int
 (** The function [get_default_sslport ()] returns the https port
     number declared in the config file ([<host
     defaulthttpsport="...">]) or 443 if undeclared.
 *)
-val get_default_sslport : unit -> int
 
+val default_protocol_is_https : unit -> bool
 (** The function [default_protocol_is_https ()] returns [true]
     if there is option ([<host
     defaultprotocol="https">])or false otherwise.
     In that case, absolute links will use https protocol even if
     the current request is http.
 *)
-val default_protocol_is_https : unit -> bool
 
+val get_config_default_charset : unit -> string
 (** The function [get_config_default_charset ()] returns the default
     charset for this site. *)
-val get_config_default_charset : unit -> string
 
+val set_default_links_xhr : ?override_configfile:bool -> bool -> unit
 (** The provided value serves as a default value for the optional parameter
     [~xhr] in the functions [Eliom_registration.*.{a, get_form, post_form,
     lwt_get_form, lwt_post_form}] (cf. {!Eliom_registration.Html.a} et al.).
     This value can also be set in the
     {{:http://ocsigen.org/eliom/dev/manual/config#h5o-25}config file}.  *)
-val set_default_links_xhr : ?override_configfile:bool -> bool -> unit
 
 (**/**)
+
 val get_default_links_xhr : unit -> bool
+
 (**/**)
 
+val get_config : unit -> Xml.xml list
 (** The function [get_config ()] returns the information of the
     configuration file concerning that site (between [<eliommodule>] and
     [</eliommodule>] or [<eliom>] and [</eliom>]).
@@ -89,29 +91,33 @@ val get_default_links_xhr : unit -> bool
     function inside the initialisation function given to
     {!Eliom_service.register_eliom_module}.}
 *)
-val get_config : unit -> Xml.xml list
 
+val parse_config
+  :  ?pcdata:(string -> unit)
+  -> ?other_elements:(string -> (string * string) list -> Xml.xml list -> unit)
+  -> Ocsigen_extensions.Configuration.element list
+  -> unit
 (** Process the configuration
     (same as the one returned by
     {% <<a_api module="Eliom_config" | val get_config>> %})
     by a given specification (cf. {% <<a_api project="ocsigenserver" | type Ocsigen_extensions.Configuration.element >> %}) *)
-val parse_config : ?pcdata:(string -> unit) -> ?other_elements:(string -> (string * string) list -> Xml.xml list -> unit) -> Ocsigen_extensions.Configuration.element list -> unit
 
+val get_config_info : unit -> Ocsigen_extensions.config_info
 (** The function [get_config_info ()] returns the information
     concerning the current request from the configuration files
     (must be called during a request).
     The configuration may have been modified by previous Ocsigen server
     extensions.
 *)
-val get_config_info : unit -> Ocsigen_extensions.config_info
 
+val get_debugmode : unit -> bool
 (** Same as [Ocsigen_config.get_debugmode].
     On client side, returns [false] for now. *)
-val get_debugmode : unit -> bool
 
 (**/**)
-val get_config_info_sp :
-  Eliom_common.server_params -> Ocsigen_extensions.config_info
 
-val get_config_default_charset_sp :
-  Eliom_common.server_params -> string
+val get_config_info_sp
+  :  Eliom_common.server_params
+  -> Ocsigen_extensions.config_info
+
+val get_config_default_charset_sp : Eliom_common.server_params -> string
