@@ -18,18 +18,17 @@
  *)
 
 open Eliom_content_core
-
 module Xml = Eliom_content_core.Xml
-
 module Xml_shared = Eliom_shared_content.Xml
 
 module Svg = struct
-
   module F = Svg.F
   module D = Svg.D
+
   module R = struct
     module Raw = Eliom_shared_content.Svg.R
     include Raw
+
     let pcdata _ = `Unimplemented
   end
 
@@ -42,51 +41,56 @@ module Svg = struct
   type uri = F.uri
 
   module Printer = Svg.Printer
-
 end
 
 module Html = struct
-
   module F = struct
     include Html.F
+
     module Arg = struct
       include Html.F
       module Svg = Eliom_content_core.Svg.F
+
       let uri_of_fun = Eliom_content_core.Xml.uri_of_fun
+
       let attrib_of_service s info =
-        Eliom_content_core.
-          (Html.F.to_attrib
-             (Xml.internal_event_handler_attrib
-                s (Xml.internal_event_handler_of_service info)))
+        Eliom_content_core.(
+          Html.F.to_attrib
+            (Xml.internal_event_handler_attrib s
+               (Xml.internal_event_handler_of_service info)))
+
       let to_elt = toelt
     end
-    include Eliom_form.Make_links(Arg)
-    module Form = Eliom_form.Make(Arg)
+
+    include Eliom_form.Make_links (Arg)
+    module Form = Eliom_form.Make (Arg)
   end
 
   module D = struct
     include Html.D
+
     module Arg = struct
       include Html.D
       module Svg = Eliom_content_core.Svg.D
+
       let uri_of_fun = Eliom_content_core.Xml.uri_of_fun
+
       let attrib_of_service s info =
-        Eliom_content_core.
-          (Html.D.to_attrib
-             (Xml.internal_event_handler_attrib
-                s (Xml.internal_event_handler_of_service info)))
+        Eliom_content_core.(
+          Html.D.to_attrib
+            (Xml.internal_event_handler_attrib s
+               (Xml.internal_event_handler_of_service info)))
+
       let to_elt = toelt
     end
-    include Eliom_form.Make_links(Arg)
-    module Form = Eliom_form.Make(Arg)
+
+    include Eliom_form.Make_links (Arg)
+    module Form = Eliom_form.Make (Arg)
   end
 
   module R = Eliom_shared_content.Html.R
-
   module Custom_data = Eliom_content_core.Html.Custom_data
-
   module Id = Html.Id
-
   module Printer = Html.Printer
 
   type +'a elt = 'a F.elt
@@ -95,5 +99,4 @@ module Html = struct
   type 'a attrib = 'a F.attrib
   type uri = F.uri
   type 'a form_param = 'a Eliom_form.param
-
 end
