@@ -17,14 +17,37 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *)
 
-type button_type = [ `Button | `Reset | `Submit ]
+type button_type = [`Button | `Reset | `Submit]
 
 module type LINKS = sig
-
   type +'a elt
   type +'a attrib
   type uri
 
+  val make_uri
+    :  ?absolute:bool
+    -> ?absolute_path:bool
+    -> ?https:bool
+    -> service:
+         ( 'get
+         , unit
+         , Eliom_service.get
+         , _
+         , _
+         , _
+         , _
+         , _
+         , _
+         , unit
+         , _ )
+         Eliom_service.t
+    -> ?hostname:string
+    -> ?port:int
+    -> ?fragment:string
+    -> ?keep_nl_params:[`All | `Persistent | `None]
+    -> ?nl_params:Eliom_parameter.nl_params_set
+    -> 'get
+    -> uri
   (** The function [make_uri service get_params] returns the URL of
       the service [service] applied to the GET parameters
       [get_params]. By default the returned URL is relative to the
@@ -96,21 +119,8 @@ module type LINKS = sig
       more information about {% <<a_manual chapter="server-params"
       fragment="nonlocalizedparameters"|non localized
       parameters>>%}.  *)
-  val make_uri :
-    ?absolute:bool ->
-    ?absolute_path:bool ->
-    ?https:bool ->
-    service:
-      ('get, unit, Eliom_service.get, _, _, _, _, _, _, unit, _)
-        Eliom_service.t ->
-    ?hostname:string ->
-    ?port:int ->
-    ?fragment:string ->
-    ?keep_nl_params:[ `All | `Persistent | `None ] ->
-    ?nl_params: Eliom_parameter.nl_params_set ->
-    'get ->
-    uri
 
+  val uri_of_string : (unit -> string) -> uri
   (** The function [uri_of_string f] returns a URI whose content is
       equivalent to [f ()].
 
@@ -121,8 +131,12 @@ module type LINKS = sig
       of a service handler.
 
       For other module, the function [f] is immediately applied. *)
-  val uri_of_string : (unit -> string) -> uri
 
+  val css_link
+    :  ?a:[< Html_types.link_attrib] attrib list
+    -> uri:uri
+    -> unit
+    -> [> Html_types.link] elt
   (** The function [css_link ~uri ()] creates a [<link>] node that
       reference a Cascading StyleSheet (CSS).
 
@@ -133,10 +147,12 @@ module type LINKS = sig
 
       The optional parameter [~a] allows one to add extra HTML
       attributes to the generated node.  *)
-  val css_link :
-    ?a:[< Html_types.link_attrib] attrib list ->
-    uri:uri -> unit -> [> Html_types.link] elt
 
+  val js_script
+    :  ?a:[< Html_types.script_attrib] attrib list
+    -> uri:uri
+    -> unit
+    -> [> Html_types.script] elt
   (** The function [js_script ~uri ()] creates a [<script>] node that
       reference a javascript file.
 
@@ -147,10 +163,34 @@ module type LINKS = sig
 
       The optional parameter [~a] allows one to add extra HTML
       attributes to the generated node.  *)
-  val js_script :
-    ?a:[< Html_types.script_attrib] attrib list -> uri:uri -> unit ->
-    [> Html_types.script] elt
 
+  val a
+    :  ?absolute:bool
+    -> ?absolute_path:bool
+    -> ?https:bool
+    -> ?a:[< Html_types.a_attrib] attrib list
+    -> service:
+         ( 'get
+         , unit
+         , Eliom_service.get
+         , _
+         , _
+         , _
+         , _
+         , _
+         , _
+         , unit
+         , Eliom_service.non_ocaml )
+         Eliom_service.t
+    -> ?hostname:string
+    -> ?port:int
+    -> ?fragment:string
+    -> ?keep_nl_params:[`All | `Persistent | `None]
+    -> ?nl_params:Eliom_parameter.nl_params_set
+    -> ?xhr:bool
+    -> 'a elt list
+    -> 'get
+    -> [> 'a Html_types.a] elt
   (** The function [a service a_content get_params] creates a [<a>]
       node that link to [service] applied to GET parameters
       [get_params] and whose content is [a_content]. By default, the
@@ -179,71 +219,87 @@ module type LINKS = sig
       To create a [<a>] node that is not associated to a service, use
       [Raw.a].
   *)
-  val a :
-    ?absolute:bool ->
-    ?absolute_path:bool ->
-    ?https:bool ->
-    ?a:[< Html_types.a_attrib] attrib list ->
-    service:
-      ('get, unit, Eliom_service.get, _, _, _, _,
-       _, _, unit, Eliom_service.non_ocaml) Eliom_service.t ->
-    ?hostname:string ->
-    ?port:int ->
-    ?fragment:string ->
-    ?keep_nl_params:[ `All | `Persistent | `None ] ->
-    ?nl_params: Eliom_parameter.nl_params_set ->
-    ?xhr:bool ->
-    'a elt list ->
-    'get ->
-    [> 'a Html_types.a] elt
-
 end
 
 module type S = sig
-
   (* When modifying this interface, please ensure that the ocamldoc is
    coherent with the ocamldoc from Eliom_uri. *)
 
   open Eliom_lib
-
   open Eliom_parameter
 
   type 'a param
-
   type +'a elt
   type +'a attrib
-
   type uri
 
   val float : float param
   val int : int param
   val int32 : int32 param
-  val int64: int64 param
+  val int64 : int64 param
   val nativeint : nativeint param
   val bool : bool param
   val string : string param
   val user : ('a -> string) -> 'a param
 
+  val make_post_uri_components
+    :  ?absolute:bool
+    -> ?absolute_path:bool
+    -> ?https:bool
+    -> service:
+         ( 'get
+         , 'post
+         , Eliom_service.post
+         , _
+         , _
+         , _
+         , _
+         , _
+         , _
+         , _
+         , _ )
+         Eliom_service.t
+    -> ?hostname:string
+    -> ?port:int
+    -> ?fragment:string
+    -> ?keep_nl_params:[`All | `Persistent | `None]
+    -> ?nl_params:Eliom_parameter.nl_params_set
+    -> ?keep_get_na_params:bool
+    -> 'get
+    -> 'post
+    -> string
+       * (string * Eliommod_parameters.param) list
+       * string option
+       * (string * Eliommod_parameters.param) list
   (** Same as {!LINK.make_uri_components}, but also returns a list of
       post parameters. *)
-  val make_post_uri_components :
-    ?absolute:bool ->
-    ?absolute_path:bool ->
-    ?https:bool ->
-    service:
-      ('get, 'post, Eliom_service.post, _, _, _, _, _, _, _, _)
-        Eliom_service.t ->
-    ?hostname:string ->
-    ?port:int ->
-    ?fragment:string ->
-    ?keep_nl_params:[ `All | `Persistent | `None ] ->
-    ?nl_params: Eliom_parameter.nl_params_set ->
-    ?keep_get_na_params:bool ->
-    'get ->
-    'post ->
-    string * (string * Eliommod_parameters.param) list * string option *
-    (string * Eliommod_parameters.param) list
 
+  val get_form
+    :  ?absolute:bool
+    -> ?absolute_path:bool
+    -> ?https:bool
+    -> ?a:[< Html_types.form_attrib] attrib list
+    -> service:
+         ( _
+         , unit
+         , Eliom_service.get
+         , _
+         , _
+         , _
+         , _
+         , _
+         , 'gn
+         , _
+         , Eliom_service.non_ocaml )
+         Eliom_service.t
+    -> ?hostname:string
+    -> ?port:int
+    -> ?fragment:string
+    -> ?keep_nl_params:[`All | `Persistent | `None]
+    -> ?nl_params:Eliom_parameter.nl_params_set
+    -> ?xhr:bool
+    -> ('gn -> [< Html_types.form_content] elt list)
+    -> [> Html_types.form] elt
   (** The function [get_form service formgen] creates a GET [<form>]
       to [service]. The content of the [<form>] is generated by the
       function [formgen], that takes the names of the service
@@ -269,42 +325,64 @@ module type S = sig
 
       See {!make_uri} for description of other optional
       parameters.  *)
-  val get_form :
-    ?absolute:bool ->
-    ?absolute_path:bool ->
-    ?https:bool ->
-    ?a:[< Html_types.form_attrib] attrib list ->
-    service:
-      (_, unit, Eliom_service.get, _, _, _, _, _,
-       'gn, _, Eliom_service.non_ocaml) Eliom_service.t ->
-    ?hostname:string ->
-    ?port:int ->
-    ?fragment:string ->
-    ?keep_nl_params:[ `All | `Persistent | `None ] ->
-    ?nl_params: Eliom_parameter.nl_params_set ->
-    ?xhr:bool ->
-    ('gn -> [< Html_types.form_content] elt list) ->
-    [> Html_types.form ] elt
 
+  val lwt_get_form
+    :  ?absolute:bool
+    -> ?absolute_path:bool
+    -> ?https:bool
+    -> ?a:[< Html_types.form_attrib] attrib list
+    -> service:
+         ( _
+         , unit
+         , Eliom_service.get
+         , _
+         , _
+         , _
+         , _
+         , _
+         , 'gn
+         , _
+         , Eliom_service.non_ocaml )
+         Eliom_service.t
+    -> ?hostname:string
+    -> ?port:int
+    -> ?fragment:string
+    -> ?keep_nl_params:[`All | `Persistent | `None]
+    -> ?nl_params:Eliom_parameter.nl_params_set
+    -> ?xhr:bool
+    -> ('gn -> [< Html_types.form_content] elt list Lwt.t)
+    -> [> Html_types.form] elt Lwt.t
   (** Same as {!get_form} but taking a cooperative function for
       [<form>] content generation. *)
-  val lwt_get_form :
-    ?absolute:bool ->
-    ?absolute_path:bool ->
-    ?https:bool ->
-    ?a:[< Html_types.form_attrib] attrib list ->
-    service:
-      (_, unit, Eliom_service.get, _, _, _, _, _,
-       'gn, _, Eliom_service.non_ocaml) Eliom_service.t ->
-    ?hostname:string ->
-    ?port:int ->
-    ?fragment:string ->
-    ?keep_nl_params:[ `All | `Persistent | `None ] ->
-    ?nl_params: Eliom_parameter.nl_params_set ->
-    ?xhr:bool ->
-    ('gn -> [< Html_types.form_content] elt list Lwt.t) ->
-    [> Html_types.form ] elt Lwt.t
 
+  val post_form
+    :  ?absolute:bool
+    -> ?absolute_path:bool
+    -> ?https:bool
+    -> ?a:[< Html_types.form_attrib] attrib list
+    -> service:
+         ( 'get
+         , _
+         , Eliom_service.post
+         , _
+         , _
+         , _
+         , _
+         , _
+         , _
+         , 'pn
+         , Eliom_service.non_ocaml )
+         Eliom_service.t
+    -> ?hostname:string
+    -> ?port:int
+    -> ?fragment:string
+    -> ?keep_nl_params:[`All | `Persistent | `None]
+    -> ?keep_get_na_params:bool
+    -> ?nl_params:Eliom_parameter.nl_params_set
+    -> ?xhr:bool
+    -> ('pn -> [< Html_types.form_content] elt list)
+    -> 'get
+    -> [> Html_types.form] elt
   (** The function [post_form service formgen post_params] creates a
       POST [<form>] to [service] preapplied to the POST parameters
       [post_params]. The content of the [<form>] is generated by the
@@ -318,130 +396,133 @@ module type S = sig
       See {!Eliom_service.make} for a description of the
       [~keep_get_na_params] optional parameter ; see {!get_form} for
       [~xhr] and see {!make_uri} for other optional parameters.  *)
-  val post_form :
-    ?absolute:bool ->
-    ?absolute_path:bool ->
-    ?https:bool ->
-    ?a:[< Html_types.form_attrib] attrib list ->
-    service:
-      ('get, _, Eliom_service.post, _, _, _, _, _,
-       _, 'pn, Eliom_service.non_ocaml) Eliom_service.t ->
-    ?hostname:string ->
-    ?port:int ->
-    ?fragment:string ->
-    ?keep_nl_params:[ `All | `Persistent | `None ] ->
-    ?keep_get_na_params:bool ->
-    ?nl_params: Eliom_parameter.nl_params_set ->
-    ?xhr:bool ->
-    ('pn -> [< Html_types.form_content] elt list) ->
-    'get ->
-    [> Html_types.form ] elt
 
+  val lwt_post_form
+    :  ?absolute:bool
+    -> ?absolute_path:bool
+    -> ?https:bool
+    -> ?a:[< Html_types.form_attrib] attrib list
+    -> service:
+         ( 'get
+         , _
+         , Eliom_service.post
+         , _
+         , _
+         , _
+         , _
+         , _
+         , _
+         , 'pn
+         , Eliom_service.non_ocaml )
+         Eliom_service.t
+    -> ?hostname:string
+    -> ?port:int
+    -> ?fragment:string
+    -> ?keep_nl_params:[`All | `Persistent | `None]
+    -> ?keep_get_na_params:bool
+    -> ?nl_params:Eliom_parameter.nl_params_set
+    -> ?xhr:bool
+    -> ('pn -> [< Html_types.form_content] elt list Lwt.t)
+    -> 'get
+    -> [> Html_types.form] elt Lwt.t
   (** Same as {!post_form} but taking a cooperative function for
       [<form>] content generation. *)
-  val lwt_post_form :
-    ?absolute:bool ->
-    ?absolute_path:bool ->
-    ?https:bool ->
-    ?a:[< Html_types.form_attrib] attrib list ->
-    service:
-      ('get, _, Eliom_service.post, _, _, _, _, _,
-       _, 'pn, Eliom_service.non_ocaml) Eliom_service.t ->
-    ?hostname:string ->
-    ?port:int ->
-    ?fragment:string ->
-    ?keep_nl_params:[ `All | `Persistent | `None ] ->
-    ?keep_get_na_params:bool ->
-    ?nl_params: Eliom_parameter.nl_params_set ->
-    ?xhr:bool ->
-    ('pn -> [< Html_types.form_content] elt list Lwt.t) ->
-    'get ->
-    [> Html_types.form ] elt Lwt.t
 
+  val input
+    :  ?a:[< Html_types.input_attrib] attrib list
+    -> input_type:[< Html_types.input_type]
+    -> ?name:[< 'a setoneradio] param_name
+    -> ?value:'a
+    -> 'a param
+    -> [> Html_types.input] elt
   (** Creates an [<input>] tag. *)
-  val input :
-    ?a:[< Html_types.input_attrib] attrib list ->
-    input_type:[< Html_types.input_type] ->
-    ?name:[< 'a setoneradio] param_name ->
-    ?value:'a ->
-    'a param ->
-    [> Html_types.input] elt
 
+  val file_input
+    :  ?a:[< Html_types.input_attrib] attrib list
+    -> name:[< file_info setoneradio] param_name
+    -> unit
+    -> [> Html_types.input] elt
   (** Creates an [<input>] tag for sending a file *)
-  val file_input :
-    ?a:[< Html_types.input_attrib] attrib list ->
-    name:[< file_info setoneradio ] param_name ->
-    unit ->
-    [> Html_types.input] elt
 
+  val image_input
+    :  ?a:[< Html_types.input_attrib] attrib list
+    -> name:[< coordinates oneradio] param_name
+    -> ?src:uri
+    -> unit
+    -> [> Html_types.input] elt
   (** Creates an [<input type="image" name="...">] tag. The server
       receives the coordinates that the user clicked on. *)
-  val image_input :
-    ?a:[< Html_types.input_attrib] attrib list ->
-    name:[< coordinates oneradio ] param_name ->
-    ?src:uri ->
-    unit ->
-    [> Html_types.input] elt
 
+  val checkbox
+    :  ?a:[< Html_types.input_attrib] attrib list
+    -> ?checked:bool
+    -> name:[`Set of 'a] Eliom_parameter.param_name
+    -> value:'a
+    -> 'a param
+    -> [> Html_types.input] elt
   (** Creates a checkbox [<input>] tag. You can produce several
       checkboxes with the same name (and different values). The
       service must declare a parameter of type [set]. *)
-  val checkbox :
-    ?a:[< Html_types.input_attrib] attrib list -> ?checked:bool ->
-    name:[ `Set of 'a ] Eliom_parameter.param_name -> value:'a ->
-    'a param ->
-    [> Html_types.input] elt
 
+  val bool_checkbox_one
+    :  ?a:[< Html_types.input_attrib] attrib list
+    -> ?checked:bool
+    -> name:[`One of bool] Eliom_parameter.param_name
+    -> unit
+    -> [> Html_types.input] elt
   (** Creates a checkbox [<input>] tag of type bool. Only one checkbox
       with the same [name] is allowed. *)
-  val bool_checkbox_one :
-    ?a:[< Html_types.input_attrib] attrib list -> ?checked:bool ->
-    name:[ `One of bool ] Eliom_parameter.param_name ->
-    unit ->
-    [> Html_types.input] elt
 
+  val radio
+    :  ?a:[< Html_types.input_attrib] attrib list
+    -> ?checked:bool
+    -> name:[`Radio of 'a] param_name
+    -> value:'a
+    -> 'a param
+    -> [> Html_types.input] elt
   (** Creates a radio [<input>] tag. *)
-  val radio :
-    ?a:[< Html_types.input_attrib] attrib list -> ?checked:bool ->
-    name:[ `Radio of 'a ] param_name ->
-    value:'a ->
-    'a param ->
-    [> Html_types.input] elt
 
-  val string_radio_required :
-    ?a:[< Html_types.input_attrib] attrib list -> ?checked:bool ->
-    name:[ `One of string ] param_name ->
-    value:string -> unit ->
-    [> Html_types.input] elt
+  val string_radio_required
+    :  ?a:[< Html_types.input_attrib] attrib list
+    -> ?checked:bool
+    -> name:[`One of string] param_name
+    -> value:string
+    -> unit
+    -> [> Html_types.input] elt
 
+  val button
+    :  ?a:[< Html_types.button_attrib] attrib list
+    -> button_type:[< button_type]
+    -> name:[< 'a setone] param_name
+    -> value:'a
+    -> 'a param
+    -> Html_types.button_content elt list
+    -> [> Html_types.button] elt
   (** Creates a [<button>] tag. *)
-  val button :
-    ?a:[< Html_types.button_attrib] attrib list ->
-    button_type:[< button_type] ->
-    name:[< 'a setone ] param_name ->
-    value:'a ->
-    'a param ->
-    Html_types.button_content elt list ->
-    [> Html_types.button] elt
 
+  val button_no_value
+    :  ?a:[< Html_types.button_attrib] attrib list
+    -> button_type:[< button_type]
+    -> Html_types.button_content elt list
+    -> [> Html_types.button] elt
   (** Creates a [<button>] tag with no value. No value is sent. *)
-  val button_no_value :
-    ?a:[< Html_types.button_attrib] attrib list ->
-    button_type:[< button_type] ->
-    Html_types.button_content elt list ->
-    [> Html_types.button] elt
 
+  val textarea
+    :  ?a:[< Html_types.textarea_attrib] attrib list
+    -> name:[< string setoneradio] param_name
+    -> ?value:string
+    -> unit
+    -> [> Html_types.textarea] elt
   (** Creates a [<textarea>] tag *)
-  val textarea :
-    ?a:[< Html_types.textarea_attrib] attrib list ->
-    name:[< string setoneradio ] param_name -> ?value:string ->
-    unit -> [> Html_types.textarea] elt
 
   type 'a soption =
     Html_types.option_attrib attrib list
-    * 'a (* Content (or value if the following is present) *)
-    * Html_types.pcdata elt option (* if content different from value *)
-    * bool (* selected *)
+    * 'a
+    (* Content (or value if the following is present) *)
+    * Html_types.pcdata elt option
+    (* if content different from value *)
+    * bool
+  (* selected *)
 
   (** The type for [<select>] options and groups of options.
 
@@ -452,30 +533,29 @@ module type S = sig
       - The string in [select_opt] is the label *)
   type 'a select_opt =
     | Optgroup of
-        [ Html_types.common | `Disabled ] attrib list
+        [Html_types.common | `Disabled] attrib list
         * string (* label *)
         * 'a soption
         * 'a soption list
     | Option of 'a soption
 
+  val select
+    :  ?a:[< Html_types.select_attrib] attrib list
+    -> ?required:Html_types.pcdata elt
+    -> name:[`One of 'a] param_name
+    -> 'a param
+    -> 'a select_opt
+    -> 'a select_opt list
+    -> [> Html_types.select] elt
   (** Creates a [<select>] tag. *)
-  val select :
-    ?a:[< Html_types.select_attrib] attrib list ->
-    ?required:Html_types.pcdata elt ->
-    name:[ `One of 'a ] param_name ->
-    'a param ->
-    'a select_opt ->
-    'a select_opt list ->
-    [> Html_types.select] elt
 
+  val multiple_select
+    :  ?a:[< Html_types.select_attrib] attrib list
+    -> ?required:Html_types.pcdata elt
+    -> name:[`Set of 'a] param_name
+    -> 'a param
+    -> 'a select_opt
+    -> 'a select_opt list
+    -> [> Html_types.select] elt
   (** Creates a multiple-selection [<select>] tag. *)
-  val multiple_select :
-    ?a:[< Html_types.select_attrib] attrib list ->
-    ?required:Html_types.pcdata elt ->
-    name:[ `Set of 'a ] param_name ->
-    'a param ->
-    'a select_opt ->
-    'a select_opt list ->
-    [> Html_types.select] elt
-
 end
