@@ -21,43 +21,45 @@
     See also {% <<a_api project="ocsigenserver" | module Ocsigen_lib>> %} *)
 
 (** See {% <<a_api project="ocsigenserver"| module Ocsigen_lib>> %}. *)
-include module type of Ocsigen_lib
-  with type poly = Ocsigen_lib.poly
-  and type yesnomaybe = Ocsigen_lib.yesnomaybe
-  and type ('a, 'b) leftright = ('a, 'b) Ocsigen_lib.leftright
-  and type 'a Clist.t = 'a Ocsigen_lib.Clist.t
-  and type 'a Clist.node = 'a Ocsigen_lib.Clist.node
+include
+  module type of Ocsigen_lib
+    with type poly = Ocsigen_lib.poly
+     and type yesnomaybe = Ocsigen_lib.yesnomaybe
+     and type ('a, 'b) leftright = ('a, 'b) Ocsigen_lib.leftright
+     and type 'a Clist.t = 'a Ocsigen_lib.Clist.t
+     and type 'a Clist.node = 'a Ocsigen_lib.Clist.node
 
-include module type of Eliom_lib_base
-  with type 'a Int64_map.t = 'a Eliom_lib_base.Int64_map.t
-  with type 'a String_map.t = 'a Eliom_lib_base.String_map.t
-  with type 'a Int_map.t = 'a Eliom_lib_base.Int_map.t
+include
+  module type of Eliom_lib_base
+    with type 'a Int64_map.t = 'a Eliom_lib_base.Int64_map.t
+    with type 'a String_map.t = 'a Eliom_lib_base.String_map.t
+    with type 'a Int_map.t = 'a Eliom_lib_base.Int_map.t
 
 type file_info = Ocsigen_extensions.file_info
 
 val string_escape : string -> string
-
 val to_json : ?typ:'a Deriving_Json.t -> 'a -> string
 val of_json : ?typ:'a Deriving_Json.t -> string -> 'a
 
+val debug : ('a, unit, string, unit) format4 -> 'a
 (** Deprecated. Use Lwt_log.ign_info_f instead *)
-val debug: ('a, unit, string, unit) format4 -> 'a
 
-(** Marshal an OCaml value into a string. All characters are escaped *)
 val jsmarshal : 'a -> string
+(** Marshal an OCaml value into a string. All characters are escaped *)
 
 (** Extension of {% <<a_api project="lwt"| module Lwt_log>> %}. *)
 module Lwt_log : sig
-  include module type of Lwt_log
-  with type level = Lwt_log.level
-   and type logger = Lwt_log.logger
-   and type section = Lwt_log.section
-   and type template = Lwt_log.template
-   and module Section = Lwt_log.Section
+  include
+    module type of Lwt_log
+      with type level = Lwt_log.level
+       and type logger = Lwt_log.logger
+       and type section = Lwt_log.section
+       and type template = Lwt_log.template
+       and module Section = Lwt_log.Section
+
   val eliom : section
 end
 
-
+val make_cryptographic_safe_string : ?len:int -> unit -> string
 (** Return a base-64 encoded cryptographic safe string of the given length.
     Not implemented client-side. *)
-val make_cryptographic_safe_string : ?len:int -> unit -> string
