@@ -39,7 +39,6 @@
 (* These two dual files are to be modified together
    with compatibility issues in mind. *)
 
-
 (** Event from server to client. *)
 module Down : sig
   (** A "Down event" (AKA down-going event) is an event which occurrences are
@@ -53,9 +52,16 @@ module Down : sig
       [let e = of_react ... in ... {{ ... React.E.map f %e; ... }}]
  *)
 
-  (** The abstract type of down events. *)
   type 'a t
+  (** The abstract type of down events. *)
 
+  val of_react
+    :  ?scope:[< Eliom_comet.Channel.comet_scope]
+    -> ?throttling:float
+    -> ?name:string
+    -> ?size:int
+    -> 'a React.E.t
+    -> 'a t
   (** [of_react ?scope ?throttling ?name e] create an
       asynchronous edge originating from [e]. The parameters are:
       - [throttling]
@@ -65,19 +71,10 @@ module Down : sig
       - [size] for the size of the server side buffer.
       - [scope]
       tell which kind of channel this rely on (See [Eliom_comet.create]). *)
-  val of_react :
-    ?scope:[<Eliom_comet.Channel.comet_scope]
-    -> ?throttling:float
-    -> ?name:string
-    -> ?size:int
-    -> 'a React.E.t
-    -> 'a t
-
 end
 
 (** Event from client to server. *)
-module Up :
-sig
+module Up : sig
   (** Up events are quite different from Down events. Because of the
       asymmetrical nature of web programming and because of the reactive model
       used, an Up event must be created on the server and wrapped into a
@@ -91,15 +88,23 @@ sig
       ]
     *)
 
+  type 'a t
   (** The type of events that, while being "on the server", are triggered by
       clients. On the server such an event is /primitive/ (hence the [create]
       function) whereas it is /effect-full/ on the client. *)
-  type 'a t
 
+  val to_react : 'a t -> 'a React.E.t
   (** [to_react e] injects the up events [e] into react events so that it can
       be manipulated as a standard event. *)
-  val to_react : 'a t -> 'a React.E.t
 
+  val create
+    :  ?scope:Eliom_common.scope
+    -> ?name:string
+    -> ( 'a
+       , [`WithoutSuffix]
+       , [`One of 'a Eliom_parameter.ocaml] Eliom_parameter.param_name )
+       Eliom_parameter.params_type
+    -> 'a t
   (** [create param] creates an Up event.
       If [~name] is present, the coservice used to transmit the event will
       always have the same name, even if the server is restarted.
@@ -107,28 +112,18 @@ sig
       [`Site] if it is called during initialisation,
       [`Client_process] otherwise.
   *)
-  val create :
-       ?scope:Eliom_common.scope
-    -> ?name:string
-    -> ('a, [ `WithoutSuffix ],
-        [ `One of 'a Eliom_parameter.ocaml ] Eliom_parameter.param_name)
-         Eliom_parameter.params_type
-    -> 'a t
-
 end
 
 module S : sig
   module Down : sig
-
-    (** The abstract type of down signals. *)
     type 'a t
+    (** The abstract type of down signals. *)
 
-    val of_react :
-      ?scope:[<Eliom_comet.Channel.comet_scope]
+    val of_react
+      :  ?scope:[< Eliom_comet.Channel.comet_scope]
       -> ?throttling:float
       -> ?name:string
       -> 'a React.S.t
       -> 'a t
-
   end
 end
