@@ -40,6 +40,30 @@ open Eliom_parameter
 
 *)
 
+val make_string_uri
+  :  ?absolute:bool
+  -> ?absolute_path:bool
+  -> ?https:bool
+  -> service:
+       ( 'get
+       , unit
+       , Eliom_service.get
+       , _
+       , _
+       , _
+       , _
+       , _
+       , _
+       , unit
+       , 'return )
+       Eliom_service.t
+  -> ?hostname:string
+  -> ?port:int
+  -> ?fragment:string
+  -> ?keep_nl_params:[`All | `None | `Persistent]
+  -> ?nl_params:nl_params_set
+  -> 'get
+  -> string
 (** The function [make_string_uri ~service get_params] creates the
     string corresponding to the URL of the service [service] applied
     to the GET parameters [get_params].
@@ -57,19 +81,20 @@ open Eliom_parameter
     - the optional parameter [~https] is [true].
     - the [service] has been created with [~https:true].
     - the [service] is an external service. *)
-val make_string_uri :
-  ?absolute:bool ->
-  ?absolute_path:bool ->
-  ?https:bool ->
-  service:
-    ('get, unit, Eliom_service.get, _, _, _, _,
-     _, _, unit, 'return) Eliom_service.t ->
-  ?hostname:string ->
-  ?port:int ->
-  ?fragment:string ->
-  ?keep_nl_params:[ `All | `None | `Persistent ] ->
-  ?nl_params:nl_params_set -> 'get -> string
 
+val make_uri_components
+  :  ?absolute:bool
+  -> ?absolute_path:bool
+  -> ?https:bool
+  -> service:
+       ('get, _, Eliom_service.get, _, _, _, _, _, _, _, _) Eliom_service.t
+  -> ?hostname:string
+  -> ?port:int
+  -> ?fragment:string
+  -> ?keep_nl_params:[`All | `None | `Persistent]
+  -> ?nl_params:nl_params_set
+  -> 'get
+  -> string * (string * Eliommod_parameters.param) list * string option
 (** The function [make_uri_components service get_params] returns the
     a triplet [(path, get_params, fragment)] that is a decomposition
     of the URL of [service] applied to the GET parameters
@@ -78,42 +103,31 @@ val make_string_uri :
     See {!Eliom_registration.Html.make_uri_components} or any other
     {!Eliom_registration}[.*.make_uri_components] for a detailed
     description. *)
-val make_uri_components :
-  ?absolute:bool ->
-  ?absolute_path:bool ->
-  ?https:bool ->
-  service:
-    ('get, _, Eliom_service.get, _, _, _, _, _, _, _, _)
-      Eliom_service.t ->
-  ?hostname:string ->
-  ?port:int ->
-  ?fragment:string ->
-  ?keep_nl_params:[ `All | `None | `Persistent ] ->
-  ?nl_params:nl_params_set ->
-  'get ->
-  string * (string * Eliommod_parameters.param) list * string option
-
 
+val make_post_uri_components
+  :  ?absolute:bool
+  -> ?absolute_path:bool
+  -> ?https:bool
+  -> service:
+       ('get, 'post, Eliom_service.post, _, _, _, _, _, _, _, _) Eliom_service.t
+  -> ?hostname:string
+  -> ?port:int
+  -> ?fragment:string
+  -> ?keep_nl_params:[`All | `Persistent | `None]
+  -> ?nl_params:nl_params_set
+  -> ?keep_get_na_params:bool
+  -> 'get
+  -> 'post
+  -> string
+     * (string * Eliommod_parameters.param) list
+     * string option
+     * (string * Eliommod_parameters.param) list
 (** Same a {!make_uri_components}, but also returns a table of post
     parameters. *)
-val make_post_uri_components :
-  ?absolute:bool ->
-  ?absolute_path:bool ->
-  ?https:bool ->
-  service:
-    ('get, 'post, Eliom_service.post, _, _, _, _, _, _, _, _)
-      Eliom_service.t ->
-  ?hostname:string ->
-  ?port:int ->
-  ?fragment:string ->
-  ?keep_nl_params:[ `All | `Persistent | `None ] ->
-  ?nl_params:nl_params_set ->
-  ?keep_get_na_params:bool ->
-  'get ->
-  'post ->
-  string * (string * Eliommod_parameters.param) list * string option *
-    (string * Eliommod_parameters.param) list
 
+val make_string_uri_from_components
+  :  string * (string * Eliommod_parameters.param) list * string option
+  -> string
 (** The function [make_string_uri_from_components path get_params
     fragment] build the corresponding string URL. The [path] should
     be URL encoded.
@@ -121,17 +135,13 @@ val make_post_uri_components :
     The function {!make_string_uri} is the composition of
     {!make_uri_components} and [make_string_uri_from_components].
 *)
-val make_string_uri_from_components :
-  string * (string * Eliommod_parameters.param) list * string option -> string
 
 (** {2 Relative paths} *)
 
+val reconstruct_relative_url_path : string list -> string list -> string list
 (** The function [reconstruct_relative_url_path src dest] returns a
     path to [dest] that is relative to [src].
 *)
-val reconstruct_relative_url_path :
-  string list -> string list -> string list
-
 
 (**/**)
 
@@ -141,75 +151,75 @@ val reconstruct_relative_url_path :
    downcast a "service_method" service to "get" or "post" service. See
    Eliom_mkreg and Eliom_client. *)
 
-val make_string_uri_ :
-  ?absolute:bool ->
-  ?absolute_path:bool ->
-  ?https:bool ->
-  service:('get, _, _, _, _, _, _, _, _, _, _) Eliom_service.t ->
-  ?hostname:string ->
-  ?port:int ->
-  ?fragment:string ->
-  ?keep_nl_params:[ `All | `None | `Persistent ] ->
-  ?nl_params:nl_params_set -> 'get -> string
+val make_string_uri_
+  :  ?absolute:bool
+  -> ?absolute_path:bool
+  -> ?https:bool
+  -> service:('get, _, _, _, _, _, _, _, _, _, _) Eliom_service.t
+  -> ?hostname:string
+  -> ?port:int
+  -> ?fragment:string
+  -> ?keep_nl_params:[`All | `None | `Persistent]
+  -> ?nl_params:nl_params_set
+  -> 'get
+  -> string
 
-val make_post_uri_components__ :
-  ?absolute:bool ->
-  ?absolute_path:bool ->
-  ?https:bool ->
-  service:('get, 'post, _, _, _, _, _, _, _, _, _) Eliom_service.t ->
-  ?hostname:string ->
-  ?port:int ->
-  ?fragment:string ->
-  ?keep_nl_params:[ `All | `None | `Persistent ] ->
-  ?nl_params:nl_params_set ->
-  ?keep_get_na_params:bool ->
-  'get ->
-  'post ->
-  string * (string * Eliommod_parameters.param) list * string option *
-    (string * Eliommod_parameters.param) list
+val make_post_uri_components__
+  :  ?absolute:bool
+  -> ?absolute_path:bool
+  -> ?https:bool
+  -> service:('get, 'post, _, _, _, _, _, _, _, _, _) Eliom_service.t
+  -> ?hostname:string
+  -> ?port:int
+  -> ?fragment:string
+  -> ?keep_nl_params:[`All | `None | `Persistent]
+  -> ?nl_params:nl_params_set
+  -> ?keep_get_na_params:bool
+  -> 'get
+  -> 'post
+  -> string
+     * (string * Eliommod_parameters.param) list
+     * string option
+     * (string * Eliommod_parameters.param) list
 
+val make_uri_components_
+  :  ?absolute:bool
+  -> ?absolute_path:bool
+  -> ?https:bool
+  -> service:(_, _, _, _, _, _, _, _, _, _, _) Eliom_service.t
+  -> ?hostname:string
+  -> ?port:int
+  -> ?fragment:string
+  -> ?keep_nl_params:[`All | `None | `Persistent]
+  -> ?nl_params:nl_params_set
+  -> unit
+  -> string * (string * Eliommod_parameters.param) list * string option
 
-val make_uri_components_ :
-  ?absolute:bool ->
-  ?absolute_path:bool ->
-  ?https:bool ->
-  service:(_, _, _, _, _, _, _, _, _, _, _) Eliom_service.t ->
-  ?hostname:string ->
-  ?port:int ->
-  ?fragment:string ->
-  ?keep_nl_params:[ `All | `None | `Persistent ] ->
-  ?nl_params:nl_params_set ->
-  unit -> string * (string * Eliommod_parameters.param) list * string option
+val make_post_uri_components_
+  :  ?absolute:bool
+  -> ?absolute_path:bool
+  -> ?https:bool
+  -> service:('get, 'post, _, _, _, _, _, _, _, _, _) Eliom_service.t
+  -> ?hostname:string
+  -> ?port:int
+  -> ?fragment:string
+  -> ?keep_nl_params:[`All | `None | `Persistent]
+  -> ?nl_params:nl_params_set
+  -> ?keep_get_na_params:bool
+  -> 'get
+  -> unit
+  -> string
+     * (string * Eliommod_parameters.param) list
+     * string option
+     * (string * Eliommod_parameters.param) list
 
-val make_post_uri_components_ :
-  ?absolute:bool ->
-  ?absolute_path:bool ->
-  ?https:bool ->
-  service:('get, 'post, _, _, _, _, _, _, _, _, _) Eliom_service.t ->
-  ?hostname:string ->
-  ?port:int ->
-  ?fragment:string ->
-  ?keep_nl_params:[ `All | `None | `Persistent ] ->
-  ?nl_params:nl_params_set ->
-  ?keep_get_na_params:bool ->
-  'get ->
-  unit ->
-  string * (string * Eliommod_parameters.param) list * string option *
-    (string * Eliommod_parameters.param) list
-
-
-
-
-val make_actual_path: string list -> string list
+val make_actual_path : string list -> string list
 
+val make_proto_prefix : ?hostname:string -> ?port:int -> bool -> string
 (** Creates the string corresponding to the beginning of the URL,
     containing the scheme (protocol), server and port number (if
     necessary).  *)
-val make_proto_prefix :
-  ?hostname:string -> ?port:int ->
-  bool -> string
 
-val make_cookies_info :
-  bool option *
-  (_, _, _, _, _, _, _, _, _, _, _) Eliom_service.t ->
-  (bool * Url.path) option
+val make_cookies_info
+  :  bool option * (_, _, _, _, _, _, _, _, _, _, _) Eliom_service.t
+  -> (bool * Url.path) option
