@@ -18,19 +18,25 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *)
 val def_handler : exn -> 'b Lwt.t
-val execute :
-  float ->
-  (float ->
-  Eliom_common.info ->
-   Eliom_common.sitedata -> Ocsigen_response.t Lwt.t) ->
-  Eliom_common.info ->
-  Eliom_common.sitedata -> Ocsigen_response.t Lwt.t
-val gen :
-  Eliom_extension.eliom_extension_sig option ->
-  Eliom_common.sitedata ->
-  Ocsigen_extensions.request_state -> Ocsigen_extensions.answer Lwt.t
-val update_cookie_table :
-  ?now:float ->
-  Eliom_common.sitedata ->
-  Eliom_common.tables Eliom_common.cookie_info ->
-  unit Lwt.t
+
+val execute
+  :  float
+  -> (float
+      -> Eliom_common.info
+      -> Eliom_common.sitedata
+      -> Ocsigen_response.t Lwt.t)
+  -> Eliom_common.info
+  -> Eliom_common.sitedata
+  -> Ocsigen_response.t Lwt.t
+
+val gen
+  :  Eliom_extension.eliom_extension_sig option
+  -> Eliom_common.sitedata
+  -> Ocsigen_extensions.request_state
+  -> Ocsigen_extensions.answer Lwt.t
+
+val update_cookie_table
+  :  ?now:float
+  -> Eliom_common.sitedata
+  -> Eliom_common.tables Eliom_common.cookie_info
+  -> unit Lwt.t
