@@ -60,7 +60,7 @@ let close_persistent_state ~scope ~secure_o ?sp () =
       let (_, _, cookie_info), secure_ci =
         Eliom_common.get_cookie_info sp cookie_level
       in
-      let sitedata = Eliom_request_info.get_sitedata_sp sp in
+      let sitedata = Eliom_request_info.get_sitedata_sp ~sp in
       let cookie_info, secure =
         compute_cookie_info sitedata secure_o secure_ci cookie_info
       in
@@ -144,7 +144,7 @@ let rec find_or_create_persistent_cookie_ ?set_max_in_group ?set_session_group
   let (_, _, cookie_info), secure_ci =
     Eliom_common.get_cookie_info sp cookie_level
   in
-  let sitedata = Eliom_request_info.get_sitedata_sp sp in
+  let sitedata = Eliom_request_info.get_sitedata_sp ~sp in
   let cookie_info, secure =
     compute_cookie_info sitedata secure_o secure_ci cookie_info
   in
@@ -205,7 +205,7 @@ let find_persistent_cookie_only ~cookie_scope ~secure_o ?sp () =
   let (_, _, cookie_info), secure_ci =
     Eliom_common.get_cookie_info sp cookie_level
   in
-  let sitedata = Eliom_request_info.get_sitedata_sp sp in
+  let sitedata = Eliom_request_info.get_sitedata_sp ~sp in
   let cookie_info, secure =
     compute_cookie_info sitedata secure_o secure_ci cookie_info
   in
